@@ -1,6 +1,5 @@
 /*
  *  methods for LUKS-related key-management for cryptmount
- *  $Revision: 258 $, $Date: 2009-05-04 07:07:04 +0100 (Mon, 04 May 2009) $
  *  (C)Copyright 2005-2009, RW Penney
  */
 
@@ -194,7 +193,8 @@ static int kmluks_get_key(bound_tgtdefn_t *boundtgt,
     int64_t delta;
     const size_t namesz = LUKS_CIPHERNAME_L + LUKS_CIPHERMODE_L + 8;
 
-    km_get_passwd(tgt->ident, pw_ctxt, &passwd, 0, 0);
+    eflag = km_get_passwd(tgt->ident, pw_ctxt, &passwd, 0, 0);
+    if (eflag != ERR_NOERROR) goto bail_out;
 
     if (blockify_file(tgt->key.filename, O_RDONLY, NULL, &tgtdev, &killloop) != ERR_NOERROR) {
         fprintf(stderr, _("Failed to create loop device for LUKS keyfile\n"));
